( cd lib ; rm -rf libgcrypt.so.11 )
( cd lib ; ln -sf libgcrypt.so.11.8.2 libgcrypt.so.11 )
( cd usr/lib ; rm -rf libgcrypt.so )
( cd usr/lib ; ln -sf libgcrypt.so.11.8.2 libgcrypt.so )
( cd usr/lib ; rm -rf libgcrypt.so.11.8.2 )
( cd usr/lib ; ln -sf ../../lib/libgcrypt.so.11.8.2 libgcrypt.so.11.8.2 )
( cd usr/lib ; rm -rf libgcrypt.so.11 )
( cd usr/lib ; ln -sf libgcrypt.so.11.8.2 libgcrypt.so.11 )
